@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7962 $
-## |  Last changed: $Date: 2024-05-31 13:41:37 +0200 (Fr, 31 Mai 2024) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #'
 #' @name StageResults
@@ -1411,7 +1407,9 @@ as.data.frame.StageResults <- function(x, row.names = NULL,
         dataInput <- x[[".dataInput"]]
     }
     if (is.null(dataInput) || !inherits(dataInput, "Dataset")) {
-        stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "failed to get 'dataInput' from ", .getClassName(x))
+        stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, 
+            "failed to get 'dataInput' from ", .getClassName(x), 
+            call. = FALSE)
     }
 
     numberOfTreatments <- dataInput$getNumberOfGroups()
@@ -1432,7 +1430,8 @@ as.data.frame.StageResults <- function(x, row.names = NULL,
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'treatmentArms' (",
             .arrayToString(treatmentArmsToShow), ") must be a vector ",
-            "containing one or more values of ", .arrayToString(validComparisons)
+            "containing one or more values of ", .arrayToString(validComparisons), 
+            call. = FALSE
         )
     }
     treatmentArmsToShow <- sort(unique(treatmentArmsToShow))
@@ -1445,7 +1444,9 @@ as.data.frame.StageResults <- function(x, row.names = NULL,
         dataInput <- x[[".dataInput"]]
     }
     if (is.null(dataInput) || !inherits(dataInput, "Dataset")) {
-        stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "failed to get 'dataInput' from ", .getClassName(x))
+        stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, 
+            "failed to get 'dataInput' from ", .getClassName(x), 
+            call. = FALSE)
     }
 
     numberOfPopulations <- gMax
@@ -1467,7 +1468,8 @@ as.data.frame.StageResults <- function(x, row.names = NULL,
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'populations' (",
             .arrayToString(populationsToShow), ") must be a vector ",
-            "containing one or more values of ", .arrayToString(validComparisons)
+            "containing one or more values of ", .arrayToString(validComparisons), 
+            call. = FALSE
         )
     }
     populationsToShow <- sort(unique(populationsToShow))
@@ -1520,31 +1522,84 @@ as.data.frame.StageResults <- function(x, row.names = NULL,
 #' @template return_object_ggplot
 #'
 #' @examples
+#' \dontrun{
 #' design <- getDesignGroupSequential(
 #'     kMax = 4, alpha = 0.025,
 #'     informationRates = c(0.2, 0.5, 0.8, 1),
 #'     typeOfDesign = "WT", deltaWT = 0.25
 #' )
-#'
 #' dataExample <- getDataset(
 #'     n = c(20, 30, 30),
 #'     means = c(50, 51, 55),
 #'     stDevs = c(130, 140, 120)
 #' )
-#'
 #' stageResults <- getStageResults(design, dataExample, thetaH0 = 20)
-#'
-#' \dontrun{
 #' if (require(ggplot2)) plot(stageResults, nPlanned = c(30), thetaRange = c(0, 100))
 #' }
 #'
 #' @export
 #'
-plot.StageResults <- function(x, y, ..., type = 1L,
-        nPlanned, allocationRatioPlanned = 1, # C_ALLOCATION_RATIO_DEFAULT
-        main = NA_character_, xlab = NA_character_, ylab = NA_character_,
-        legendTitle = NA_character_, palette = "Set1", legendPosition = NA_integer_,
-        showSource = FALSE, plotSettings = NULL) {
+plot.StageResults <- function(
+        x, 
+        y, 
+        ..., 
+        type = 1L,
+        nPlanned, 
+        allocationRatioPlanned = 1, # C_ALLOCATION_RATIO_DEFAULT
+        main = NA_character_, 
+        xlab = NA_character_, 
+        ylab = NA_character_,
+        legendTitle = NA_character_, 
+        palette = "Set1", 
+        legendPosition = NA_integer_,
+        showSource = FALSE, 
+        plotSettings = NULL) {
+    
+    markdown <- .getOptionalArgument("markdown", ..., optionalArgumentDefaultValue = NA)
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled("plot")
+    }
+    
+    args <- list(
+        x = x, 
+        y = NULL,
+        type = type,
+        nPlanned = nPlanned,
+        allocationRatioPlanned = allocationRatioPlanned,
+        main = main,
+        xlab = xlab,
+        ylab = ylab,
+        legendTitle = legendTitle,
+        palette = palette,
+        legendPosition = legendPosition,
+        showSource = showSource,
+        plotSettings = plotSettings, 
+        ...)
+    
+    if (markdown) {
+        sep <- .getMarkdownPlotPrintSeparator()
+        print(do.call(.plot.StageResults, args))
+        return(.knitPrintQueue(x, sep = sep, prefix = sep))
+    }
+    
+    return(do.call(.plot.StageResults, args))
+}
+
+.plot.StageResults <- function(
+        x, 
+        y, 
+        ..., 
+        type = 1L,
+        nPlanned, 
+        allocationRatioPlanned = 1, # C_ALLOCATION_RATIO_DEFAULT
+        main = NA_character_, 
+        xlab = NA_character_, 
+        ylab = NA_character_,
+        legendTitle = NA_character_, 
+        palette = "Set1", 
+        legendPosition = NA_integer_,
+        showSource = FALSE, 
+        plotSettings = NULL) {
     fCall <- match.call(expand.dots = FALSE)
 
     .assertGgplotIsInstalled()
@@ -1556,7 +1611,9 @@ plot.StageResults <- function(x, y, ..., type = 1L,
     .stopInCaseOfIllegalStageDefinition2(...)
 
     if (x$.design$kMax == 1) {
-        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "cannot plot stage results of a fixed design")
+        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
+            "cannot plot stage results of a fixed design", 
+            call. = FALSE)
     }
 
     if (!is.logical(showSource) || isTRUE(showSource)) {
@@ -1591,8 +1648,10 @@ plot.StageResults <- function(x, y, ..., type = 1L,
     }
 
     plotData <- .getConditionalPowerPlot(
-        stageResults = x, nPlanned = nPlanned,
-        allocationRatioPlanned = allocationRatioPlanned, ...
+        stageResults = x, 
+        nPlanned = nPlanned,
+        allocationRatioPlanned = allocationRatioPlanned, 
+        ...
     )
 
     yParameterName1 <- "Conditional power"
