@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8752 $
-## |  Last changed: $Date: 2025-07-10 14:29:45 +0200 (Do, 10 Jul 2025) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #' @include class_dictionary.R
 #' @include f_core_utilities.R
@@ -70,6 +66,7 @@ C_ALPHA_0_VEC_DEFAULT <- 1
 C_THETA_H0_MEANS_DEFAULT <- 0
 C_THETA_H0_RATES_DEFAULT <- 0
 C_THETA_H0_SURVIVAL_DEFAULT <- 1
+C_THETA_H0_COUNTS_DEFAULT <- 1
 C_ALLOCATION_RATIO_DEFAULT <- 1
 C_ALLOCATION_RATIO_MAXIMUM <- 100
 C_DIRECTION_UPPER_DEFAULT <- TRUE
