@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7742 $
-## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #' @include f_core_assertions.R
 #' @include f_core_utilities.R
@@ -27,7 +23,7 @@ NULL
 }
 
 .getDefaultDesign <- function(...,
-        type = c("sampleSize", "power", "simulation", "analysis", "characteristics"),
+        type = c("sampleSize", "power", "simulation", "simulationCounts", "analysis", "characteristics"),
         ignore = c()) {
     type <- match.arg(type)
 
@@ -52,25 +48,40 @@ NULL
         ignore <- c(ignore, "sided")
     }
 
+    directionUpper <- .getOptionalArgument("directionUpper", ...)
+    if (is.null(directionUpper)) {
+        directionUpper <- NA
+    } else {
+        ignore <- c(ignore, "directionUpper")
+    }
+
     twoSidedPower <- .getOptionalArgument("twoSidedPower", ...)
     if (is.null(twoSidedPower)) {
-        if (type %in% c("power", "simulation") && sided == 2) {
+        if (type %in% c("power", "simulation", "simulationCounts") && sided == 2) {
             twoSidedPower <- TRUE
         } else {
-            twoSidedPower <- C_TWO_SIDED_POWER_DEFAULT
+            twoSidedPower <- NA
         }
     } else {
         ignore <- c(ignore, "twoSidedPower")
     }
     if (type %in% c("analysis", "simulation")) {
         design <- getDesignInverseNormal(
-            kMax = 1, alpha = alpha, beta = beta,
-            sided = sided, twoSidedPower = twoSidedPower
+            kMax = 1,
+            alpha = alpha,
+            beta = beta,
+            sided = sided,
+            twoSidedPower = twoSidedPower,
+            directionUpper = directionUpper
         )
     } else {
         design <- getDesignGroupSequential(
-            kMax = 1, alpha = alpha, beta = beta,
-            sided = sided, twoSidedPower = twoSidedPower
+            kMax = 1,
+            alpha = alpha,
+            beta = beta,
+            sided = sided,
+            twoSidedPower = twoSidedPower,
+            directionUpper = directionUpper
         )
     }
     return(design)
@@ -232,7 +243,7 @@ NULL
             ") will be ignored because it will be calculated",
             call. = FALSE
         )
-    } else if (design$.getParameterType(parameterName) == C_PARAM_GENERATED) {
+    } else if (design$isGeneratedParameter(parameterName)) {
         return(FALSE)
     }
 
@@ -382,6 +393,13 @@ NULL
             design$kMax, design$alpha
         ))
     }
+
+    if (design$kMax > 2 && (any(design$userAlphaSpending[2:design$kMax] - design$userAlphaSpending[1:(design$kMax - 1)] < design$tolerance))) {
+        warning("Chosen 'userAlphaSpending' (", .arrayToString(design$userAlphaSpending, vectorLookAndFeelEnabled = FALSE),
+            ") might yield imprecise critical values due to numerical inaccuracy",
+            call. = FALSE
+        )
+    }
 }
 
 .validateUserBetaSpending <- function(design) {
@@ -441,6 +459,13 @@ NULL
             design$kMax, design$beta
         ))
     }
+
+    if (design$kMax > 2 && (any(design$userBetaSpending[2:design$kMax] - design$userBetaSpending[1:(design$kMax - 1)] < design$tolerance))) {
+        warning("Chosen 'userBetaSpending' (", .arrayToString(design$userBetaSpending, vectorLookAndFeelEnabled = FALSE),
+            ") might yield imprecise futility bounds due to numerical inaccuracy",
+            call. = FALSE
+        )
+    }
 }
 
 .validateUserAlphaSpendingLength <- function(design) {
@@ -695,6 +720,7 @@ NULL
 #' @return A \code{\link[base]{numeric}} value or vector will be returned.
 #'
 #' @examples
+#' \dontrun{
 #' # Calculate probabilties for a range of time values for a
 #' # piecewise exponential distribution with hazard rates
 #' # 0.025, 0.04, 0.015, and 0.007 in the intervals
@@ -712,6 +738,7 @@ NULL
 #' getPiecewiseExponentialQuantile(y,
 #'     piecewiseSurvivalTime = piecewiseSurvivalTime
 #' )
+#' }
 #'
 #' @name utilitiesForPiecewiseExponentialDistribution
 #'
@@ -871,7 +898,7 @@ getLambdaByPi <- function(piValue,
     .assertIsSingleNumber(eventTime, "eventTime")
     .assertIsInOpenInterval(eventTime, "eventTime", lower = 0, upper = NULL)
     for (value in piValue) {
-        if (value > 1 - 1e-16 && value < 1 + 1e-16) {
+        if (!is.na(value) && value > 1 - 1e-16 && value < 1 + 1e-16) {
             stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'pi' must be != 1")
         }
     }
@@ -909,7 +936,7 @@ getPiByLambda <- function(lambda,
     .assertIsSingleNumber(eventTime, "eventTime")
     .assertIsInOpenInterval(eventTime, "eventTime", lower = 0, upper = NULL)
     x <- exp(-(lambda * eventTime)^kappa)
-    if (any(x < 1e-15)) {
+    if (any(x < 1e-15, na.rm = TRUE)) {
         warning("Calculation of pi (1) by lambda (", .arrayToString(round(lambda, 4)),
             ") results in a possible loss of precision because pi = 1 was returned but pi is not exactly 1",
             call. = FALSE
