@@ -14,14 +14,12 @@
  *
  * Contact us for information about our services: info@rpact.com
  *
- * File version: $Revision: 6416 $
- * Last changed: $Date: 2022-07-15 09:24:06 +0200 (Fr, 15 Jul 2022) $
- * Last changed by: $Author: pahlke $
- *
  */
 
-// [[Rcpp::plugins(cpp11)]]
 #include <Rcpp.h>
+
+// [[Rcpp::plugins(cpp11)]]
+
 #include "f_utilities.h"
 
 using namespace Rcpp;
@@ -45,7 +43,7 @@ double findObservationTime(
 			}
 		}
 		upperBound = 2 * upperBound;
-		if (numberOfEvents > requiredStageEvents || upperBound > 1E12) {
+		if (numberOfEvents >= requiredStageEvents || upperBound > 1E12) {
 			break;
 		}
 	}
