@@ -14,10 +14,6 @@
  *
  * Contact us for information about our services: info@rpact.com
  *
- * File version: $Revision: 4248 $
- * Last changed: $Date: 2021-01-22 15:57:53 +0100 (Fri, 22 Jan 2021) $
- * Last changed by: $Author: pahlke $
- *
  */
 
 #include <Rcpp.h>
@@ -29,6 +25,21 @@ using namespace Rcpp;
 #ifndef PKG_RPACT_H
 #define PKG_RPACT_H
 
+struct Exception : std::exception {
+    char text[1000];
+
+    Exception(char const* fmt, ...) __attribute__((format(printf,2,3))) {
+        va_list ap;
+        va_start(ap, fmt);
+        vsnprintf(text, sizeof text, fmt, ap);
+        va_end(ap);
+    }
+
+    char const* what() const throw() {
+    	return text;
+    }
+};
+
 double getQNormEpsilon();
 
 double getQNormThreshold();
